@@ -18,10 +18,18 @@ class ComponentSpecificParametersEnum:
 
     # structural components
     # ---------
+    # AZDOCK
     __AZDOCK_CONFPATH = "configuration_path"
     __AZDOCK_DOCKERSCRIPTPATH = "docker_script_path"
     __AZDOCK_ENVPATH = "environment_path"
     __AZDOCK_DEBUG = "debug"
+
+    # AZGARD
+    __AZGARD_CONFPATH = "configuration_path"
+    __AZGARD_EXECUTORSCRIPTPATH = "executor_script_path"
+    __AZGARD_ENVPATH = "environment_path"
+    __AZGARD_VALUES_KEY = "values_key"
+    __AZGARD_DEBUG = "debug"
     #######################
 
     __RAT_PK_PROPERTY = "rat_pk_property"
@@ -93,6 +101,46 @@ class ComponentSpecificParametersEnum:
     def AZDOCK_ENVPATH(self, value):
         raise ValueError("Do not assign value to a ComponentSpecificParametersEnum field")
 
+    @property
+    def AZGARD_DEBUG(self):
+        return self.__AZGARD_DEBUG
+
+    @AZGARD_DEBUG.setter
+    def AZGARD_DEBUG(self, value):
+        raise ValueError("Do not assign value to a ComponentSpecificParametersEnum field")
+
+    @property
+    def AZGARD_CONFPATH(self):
+        return self.__AZGARD_CONFPATH
+
+    @AZGARD_CONFPATH.setter
+    def AZGARD_CONFPATH(self, value):
+        raise ValueError("Do not assign value to a ComponentSpecificParametersEnum field")
+
+    @property
+    def AZGARD_EXECUTORSCRIPTPATH(self):
+        return self.__AZGARD_EXECUTORSCRIPTPATH
+
+    @AZGARD_EXECUTORSCRIPTPATH.setter
+    def AZGARD_EXECUTORSCRIPTPATH(self, value):
+        raise ValueError("Do not assign value to a ComponentSpecificParametersEnum field")
+
+    @property
+    def AZGARD_VALUES_KEY(self):
+        return self.__AZGARD_VALUES_KEY
+
+    @AZGARD_VALUES_KEY.setter
+    def AZGARD_VALUES_KEY(self, value):
+        raise ValueError("Do not assign value to a ComponentSpecificParametersEnum field")
+
+    @property
+    def AZGARD_ENVPATH(self):
+        return self.__AZGARD_ENVPATH
+
+    @AZGARD_ENVPATH.setter
+    def AZGARD_ENVPATH(self, value):
+        raise ValueError("Do not assign value to a ComponentSpecificParametersEnum field")
+
     @property
     def LOW(self):
         return self.__LOW
