@@ -4,23 +4,19 @@ from abc import abstractmethod
 from typing import List
 
 import numpy as np
-import rdkit.Chem as rkc
 
 from reinvent_scoring.scoring.component_parameters import ComponentParameters
 from reinvent_scoring.scoring.score_components import BaseScoreComponent
 from reinvent_scoring.scoring.score_summary import ComponentSummary
-from reinvent_scoring.scoring.score_transformations import TransformationFactory
-from reinvent_scoring.scoring.enums import TransformationTypeEnum
 
 
 class BaseClabComponent(BaseScoreComponent):
     def __init__(self, parameters: ComponentParameters):
         super().__init__(parameters)
         self._clab_input_file = self.parameters.specific_parameters[self.component_specific_parameters.CLAB_INPUT_FILE]
-        self.transformation_function = self._assign_transformation(self.parameters.specific_parameters)
 
-    def calculate_score(self, molecules: List[rkc.Mol]) -> ComponentSummary:
-        valid_smiles = [rkc.MolToSmiles(mol, isomericSmiles=False) for mol in molecules]
+    def calculate_score(self, molecules: List, step=-1) -> ComponentSummary:
+        valid_smiles = self._chemistry.mols_to_smiles(molecules)
         score, raw_score = self._calculate_score(valid_smiles)
         score_summary = ComponentSummary(total_score=score, parameters=self.parameters, raw_score=raw_score)
         return score_summary
@@ -58,7 +54,7 @@ class BaseClabComponent(BaseScoreComponent):
         transformed into 0. """
         valid_mask = ~np.isnan(results_raw)
         results_raw_valid = results_raw[valid_mask]
-        results_transformed = self.transformation_function(results_raw_valid, self.parameters.specific_parameters)
+        results_transformed = self._transformation_function(results_raw_valid, self.parameters.specific_parameters)
         results = np.zeros(len(results_raw), dtype=np.float32)
         results[valid_mask] = results_transformed
         return results
@@ -105,14 +101,3 @@ class BaseClabComponent(BaseScoreComponent):
     def _write_clab_input(self, data):
         with open(self._clab_input_file, 'w') as ofile:
             ofile.writelines(data)
-
-    def _assign_transformation(self, specific_parameters: {}):
-        transformation_type = TransformationTypeEnum()
-        factory = TransformationFactory()
-        if self.parameters.specific_parameters[self.component_specific_parameters.TRANSFORMATION]:
-            transform_function = factory.get_transformation_function(specific_parameters)
-        else:
-            self.parameters.specific_parameters[
-                self.component_specific_parameters.TRANSFORMATION_TYPE] = transformation_type.NO_TRANSFORMATION
-            transform_function = factory.no_transformation
-        return transform_function
