@@ -23,6 +23,11 @@ class BaseStructuralComponent(BaseScoreComponent):
         score_summary = ComponentSummary(total_score=score, parameters=self.parameters, raw_score=raw_score)
         return score_summary
 
+    def _get_step_string(self, step) -> str:
+        if step == -1:
+            return "\"\""
+        return "".join(["\"e", str(step).zfill(4), "_\""])
+
     @abstractmethod
     def _calculate_score(self, smiles: List[str], step) -> np.array:
         raise NotImplementedError("_calculate_score method is not implemented")
@@ -42,7 +47,3 @@ class BaseStructuralComponent(BaseScoreComponent):
             proc.wait()
             proc.terminate()
         return result
-
-    @abstractmethod
-    def _parse_result(self, result):
-        raise NotImplementedError("_parse_result method is not implemented")
